#
# spec file for package check_postgres
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           check_postgres
Version:        2.26.0
Release:        1.8
Summary:        Postgres monitoring script
License:        GPL-2.0-or-later
Group:          System/Monitoring
URL:            http://bucardo.org/wiki/Check_postgres
Source:         https://github.com/bucardo/%{name}/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        nagios-commands-postgres.cfg
Source2:        create_manpage.pl
Source3:        check_postgres.cfg
BuildRequires:  nagios-rpm-macros
BuildRequires:  perl-macros
BuildRequires:  perl(Cwd)
BuildRequires:  perl(DBD::Pg)
BuildRequires:  perl(DBI)
BuildRequires:  perl(Data::Dumper)
BuildRequires:  perl(Date::Parse)
BuildRequires:  perl(Digest::MD5)
BuildRequires:  perl(File::Basename)
BuildRequires:  perl(File::Temp)
BuildRequires:  perl(Getopt::Long)
BuildRequires:  perl(Pod::Man)
BuildRequires:  perl(Time::HiRes)
Requires:       perl = %{perl_version}
Requires:       postgresql
Requires:       perl(Cwd)
Requires:       perl(Data::Dumper)
Requires:       perl(File::Basename)
Requires:       perl(File::Temp)
Requires:       perl(Getopt::Long)
Requires:       perl(Time::HiRes)
Recommends:     coreutils
Recommends:     util-linux
Recommends:     perl(Date::Parse)
Recommends:     perl(Digest::MD5)
BuildArch:      noarch

%description
check_postgres.pl is a Perl script that runs many different tests against one
or more Postgres databases. It uses the psql program to gather the information,
and outputs the results in one of three formats: Nagios, MRTG, or simple.

%package -n monitoring-plugins-postgres
Summary:        Postgres monitoring script using check_postgres.pl
# FIXME: use proper Requires(pre/post/preun/...)
Group:          System/Monitoring
PreReq:         %{name} = %{version}
Provides:       nagios-plugins-postgres = %{version}-%{release}
Obsoletes:      nagios-plugins-postgres < %{version}-%{release}

%description -n monitoring-plugins-postgres
This package contains the symlinks to execute special checks via the standard
monitoring plugins way.

%prep
%setup -q
install -m 0644 %{SOURCE1} nagios-commands-postgres.cfg
sed -i 's|#!/usr/bin/env perl|#!/usr/bin/perl|g' check_postgres.pl

%build
perl Makefile.PL
make %{?_smp_mflags}

%install
# install the module
%perl_make_install
# do not perl_process_packlist (noarch)
# remove .packlist file
rm -rf %{buildroot}%{perl_vendorarch}
# remove perllocal.pod file
rm -rf %{buildroot}%{perl_archlib}
%perl_gen_filelist
# create symlinks for monitoring-plugins-postgres package
mkdir -p %{buildroot}%{nagios_plugindir}
pushd %{buildroot}%{nagios_plugindir}
%{buildroot}%{_bindir}/check_postgres.pl --symlinks
# fix symlinks, as they point to the buildroot
for link in *; do
	rm "$link"
	ln -s "%{_bindir}/check_postgres.pl" "$link"
done
popd
# create man page
mkdir -p %{buildroot}/%{_mandir}/man1
perl %{SOURCE2} "%{version}" "1" check_postgres.pl > %{buildroot}/%{_mandir}/man1/check_postgres.pl.1
# install nrpe snipplets
install -D -m0644 %{SOURCE3} %{buildroot}%{nrpe_sysconfdir}/check_postgres.cfg

%files -f %{name}.files
%doc MANIFEST README* TODO nagios-commands-postgres.cfg check_postgres.pl.html
%if 0%{?suse_version} > 1315
%license LICENSE
%else
%doc LICENSE
%endif
%{_mandir}/man1/check_postgres.pl.1%{?ext_man}

%files -n monitoring-plugins-postgres
# avoid build dependecy of nagios - own the dirs
%dir %{nagios_libdir}
%dir %{nagios_plugindir}
%dir %{nrpe_sysconfdir}
%config(noreplace) %{nrpe_sysconfdir}/check_postgres.cfg
%{nagios_plugindir}/*

%changelog
* Fri Apr  7 2023 Martin Hauke <mardnh@gmx.de>
- Update to version 2.26.0
  * Add new action "pgbouncer_maxwait".
  * For the bloat check, add option to populate all known databases,
    as well as includsion and exclusion regexes.
  * Add Partman premake check.
  * Add --role flag to explicitly set the role of the user after
    connecting.
  * Fix check_replication_slots on recently promoted servers.
  * Allow the check_disk_space action to handle relative
    log_directory paths.
  * Fix MINPAGES and MINIPAGES in the "check_bloat" action.
  * Replace 'which' with 'command -v'.
  * Fix check_replication_slots on recently promoted servers.
  * Fix undefined variable warning.
  * In the tests, force log_destination to stderr.
  * Add to docs how to exclude all items in the 'pg_temp_nnn'
    per-session temporary schemas.
  * Various improvements to the tests.
* Tue Mar  8 2022 Lars Vogdt <lars@linux-schulserver.de>
- added /etc/nrpe.d/check_postgres.cfg, containing some pre-configured
  nrpe checks for the different check options
* Tue Feb  4 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 2.25.0
  * Allow same_schema objects to be included or excluded with
  - -object and --skipobject
  * Fix to allow mixing service names and other connection
    parameters for same_schema
* Thu Mar 28 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 2.24.0
  * Support new_version_pg for PG10
  * Option to skip CYCLE sequences in action sequence
  * Output per-database perfdata for pgbouncer pool checks
  * German message translations
  * Consider only client backends in query_time and friends
- Use github Source URL
* Wed Mar 21 2018 lars@linux-schulserver.de
- Update to 2.23.0:
  + added support for PostgreSQL 10
  + Change table_size to use pg_table_size() on 9.0+
  + Connection errors are now always critical, not unknown
  + New action replication_slots checking if logical or physical
    replication slots have accumulated too much data
  + Multiple same_schema improvements
  + Add Spanish message translations
  + Allow a wrapper function to run wal_files and archive_ready
    actions as non-superuser
  + Add some defensive casting to the bloat query
  + Invoke psql with option -X
  + check_txn_idle: Don't fail when query contains 'disabled' word
  + check_txn_idle: Use state_change instead of query_start.
  + check_hot_standby_delay: Correct extra space in perfdata
  + Remove \r from psql output as it can confuse some regexes
  + Sort failed jobs in check_pgagent_jobs for stable output
- run spec cleaner
- use %%%%license for newer distributions
* Sat Mar 18 2017 aj@ajaissle.de
- Update to 2.22.0
* Sat Mar 18 2017 aj@ajaissle.de
- BuildRequire perl-macros to fix SLE_11_SP4 build
* Wed Jul 30 2014 lars@linux-schulserver.de
- rename subpackage to monitoring-plugins-postgres
* Tue Oct 29 2013 lars@linux-schulserver.de
- update to 2.21.0
- remove perl-macros dependency
- add check_postgres.pl man page (and script to generate it
  from source)
* Fri Aug  9 2013 darin@darins.net
- update to 2.20.1
- removed perl-marcro from .spec
* Thu Jul 12 2012 darin@darins.net
- added a sample nagios/check_mk command definition file
* Tue Jul 10 2012 darin@darins.net
- update to version 2.19.0
- cleaned up .spec
- fixed License
* Mon Feb 21 2011 lars@linux-schulserver.de
- initial version 2.16.0
- disabled make test as this breaks the build currently
- create a special nagios package containing just the symlinks
